@@ -7,18 +7,21 @@ from pyodmongo import (
     Id,
     Field,
 )
-from pyodmongo.queries import eq, gte, gt, mount_query_filter
+from pyodmongo.queries import eq, gte, gt, mount_query_filter, sort
 from pyodmongo.engine.utils import consolidate_dict
-from pydantic import ConfigDict
+from pydantic import ConfigDict, BaseModel
 from typing import ClassVar
 from bson import ObjectId
-from datetime import datetime
+from datetime import datetime, UTC, timezone, timedelta
+import pytz
 import pytest
 import pytest_asyncio
 
 mongo_uri = "mongodb://localhost:27017"
 db_name = "pyodmongo_pytest"
-db = AsyncDbEngine(mongo_uri=mongo_uri, db_name=db_name)
+db = AsyncDbEngine(
+    mongo_uri=mongo_uri, db_name=db_name, tz_info=pytz.timezone("America/Sao_Paulo")
+)
 
 
 class MyClass(DbModel):
@@ -63,7 +66,7 @@ async def test_create_and_delete_one(drop_collection, new_obj):
     result: SaveResponse = await db.save(new_obj)
     assert result.upserted_id is not None
     id = result.upserted_id
-    query = eq(MyClass.id, id)
+    query = MyClass.id == id
     result: DeleteResponse = await db.delete_one(Model=MyClass, query=query)
     assert result.deleted_count == 1
 
@@ -122,8 +125,8 @@ async def test_delete(drop_collection, objs):
 
 @pytest.mark.asyncio
 async def test_find_many_without_paginate(drop_collection, create_100_docs_in_db):
-    obj_list_50 = await db.find_many(Model=MyClass, query=gt(MyClass.random_number, 50))
-    obj_list_100 = await db.find_many(Model=MyClass, query=gt(MyClass.random_number, 0))
+    obj_list_50 = await db.find_many(Model=MyClass, query=MyClass.random_number > 50)
+    obj_list_100 = await db.find_many(Model=MyClass, query=MyClass.random_number > 0)
     assert len(obj_list_50) == 50
     assert len(obj_list_100) == 100
     assert all(isinstance(obj, MyClass) for obj in obj_list_100)
@@ -219,7 +222,7 @@ async def test_fields_alias_generator():
 async def test_find_many_with_zero_results(drop_collection):
     await db.save(obj=drop_collection)
     result = await db.find_many(
-        Model=MyClass, query=eq(MyClass.attr1, "value_that_not_exists"), paginate=True
+        Model=MyClass, query=MyClass.attr1 == "value_that_not_exists", paginate=True
     )
 
     assert result.page_quantity == 0
@@ -308,7 +311,7 @@ async def create_regex_collection():
 @pytest.mark.asyncio
 async def test_find_regex(create_regex_collection):
     input_dict = {"attr_1_in": "['/^ind[uúû]stria/i']"}
-    query = mount_query_filter(
+    query, _ = mount_query_filter(
         Model=MyModelRegex, items=input_dict, initial_comparison_operators=[]
     )
     results = await db.find_many(Model=MyModelRegex, query=query)
@@ -448,7 +451,7 @@ class ClassB(DbModel):
 
 
 @pytest_asyncio.fixture()
-async def drop_collections():
+async def drop_collections_a_b():
     await db._db[ClassA._collection].drop()
     await db._db[ClassB._collection].drop()
     yield
@@ -457,25 +460,190 @@ async def drop_collections():
 
 
 @pytest.mark.asyncio
-async def test_find_nested_field_query(drop_collections):
+async def test_find_nested_field_query(drop_collections_a_b):
     obj_a = ClassA()
     await db.save(obj=obj_a)
     obj_b = ClassB(a=obj_a)
     await db.save(obj=obj_b)
-    query = eq(ClassB.a.attr_2, "A String 2")
+    query = eq(ClassB.a, obj_a.id)
     result = await db.find_many(Model=ClassB, query=query, populate=True)
     assert result == [obj_b]
 
 
 @pytest.mark.asyncio
-async def test_find_nested_field_mount_query(drop_collections):
+async def test_find_nested_field_mount_query(drop_collections_a_b):
     obj_a = ClassA()
     await db.save(obj=obj_a)
     obj_b = ClassB(a=obj_a)
     await db.save(obj=obj_b)
-    input_dict = {"a.attr_2_eq": "A String 2"}
-    query = mount_query_filter(
+    input_dict = {"a": obj_a.id}
+    query, _ = mount_query_filter(
         Model=ClassB, items=input_dict, initial_comparison_operators=[]
     )
     result = await db.find_many(Model=ClassB, query=query, populate=True)
     assert result == [obj_b]
+
+
+class ClassOne(DbModel):
+    attr_1: str = "attr 1"
+    _collection: ClassVar = "class_one"
+
+
+class ClassTwoA(BaseModel):
+    attr_2_a: str = "attr 2 A"
+    class_one: list[ClassOne | Id] | None
+
+
+class ClassTwoB(BaseModel):
+    attr_2_b: str = "attr 2 B"
+    class_two_a: ClassTwoA | None
+    class_two_a_list: list[ClassTwoA] | None
+
+
+class ClassThree(DbModel):
+    attr_3: str = "attr 3"
+    class_two_b: ClassTwoB | None
+    class_two_b_list: list[ClassTwoB] | None
+    _collection: ClassVar = "class_three"
+
+
+@pytest_asyncio.fixture()
+async def drop_collections_one_three():
+    await db._db[ClassOne._collection].drop()
+    await db._db[ClassThree._collection].drop()
+    yield
+    await db._db[ClassOne._collection].drop()
+    await db._db[ClassThree._collection].drop()
+
+
+@pytest.mark.asyncio
+async def test_nested_list_objects(drop_collections_one_three):
+    obj_1 = ClassOne(attr_1="obj_1")
+    obj_2 = ClassOne(attr_1="obj_2")
+    obj_3 = ClassOne(attr_1="obj_3")
+    obj_4 = ClassOne(attr_1="obj_4")
+    obj_5 = ClassOne(attr_1="obj_5")
+    obj_6 = ClassOne(attr_1="obj_6")
+    obj_7 = ClassOne(attr_1="obj_7")
+    obj_8 = ClassOne(attr_1="obj_8")
+    await db.save_all([obj_1, obj_2, obj_3, obj_4, obj_5, obj_6, obj_7, obj_8])
+    obj_9 = ClassTwoA(attr_2_a="obj_9", class_one=[obj_1, obj_2])
+    obj_10 = ClassTwoA(attr_2_a="obj_10", class_one=[obj_3, obj_4])
+    obj_11 = ClassTwoA(attr_2_a="obj_11", class_one=[obj_5, obj_6])
+    obj_12 = ClassTwoA(attr_2_a="obj_12", class_one=[obj_7, obj_8])
+    obj_13 = ClassTwoB(
+        attr_2_b="obj_13", class_two_a=obj_9, class_two_a_list=[obj_9, obj_10]
+    )
+    obj_14 = ClassTwoB(
+        attr_2_b="obj_14", class_two_a=obj_11, class_two_a_list=[obj_11, obj_12]
+    )
+    obj_15 = ClassThree(
+        attr_3="obj_15", class_two_b=obj_13, class_two_b_list=[obj_13, obj_14]
+    )
+    await db.save(obj_15)
+
+    obj_found = await db.find_one(Model=ClassThree, populate=True)
+    assert obj_found.id == obj_15.id
+    assert obj_found.class_two_b.attr_2_b == "obj_13"
+
+
+class MySortClass(DbModel):
+    attr_1: str
+    attr_2: int
+    attr_3: datetime
+    _collection: ClassVar = "my_class_to_sort"
+
+
+@pytest_asyncio.fixture()
+async def drop_collection_for_test_sort():
+    await db._db[MySortClass._collection].drop()
+    yield
+    await db._db[MySortClass._collection].drop()
+
+
+@pytest.mark.asyncio
+async def test_sort_query(drop_collection_for_test_sort):
+    obj_list = [
+        MySortClass(
+            attr_1="Juliet",
+            attr_2=100,
+            attr_3=datetime(year=2023, month=1, day=20, tzinfo=UTC),
+        ),
+        MySortClass(
+            attr_1="Albert",
+            attr_2=50,
+            attr_3=datetime(year=2025, month=1, day=20, tzinfo=UTC),
+        ),
+        MySortClass(
+            attr_1="Zack",
+            attr_2=30,
+            attr_3=datetime(year=2020, month=1, day=20, tzinfo=UTC),
+        ),
+        MySortClass(
+            attr_1="Charlie",
+            attr_2=150,
+            attr_3=datetime(year=2027, month=1, day=20, tzinfo=UTC),
+        ),
+        MySortClass(
+            attr_1="Albert",
+            attr_2=40,
+            attr_3=datetime(year=2025, month=1, day=20, tzinfo=UTC),
+        ),
+    ]
+    await db.save_all(obj_list=obj_list)
+    sort_oprator = sort((MySortClass.attr_1, 1), (MySortClass.attr_2, 1))
+    result_many = await db.find_many(Model=MySortClass, sort=sort_oprator)
+    assert result_many[0] == obj_list[4]
+    assert result_many[1] == obj_list[1]
+
+    sort_oprator = sort((MySortClass.attr_3, 1))
+    result_one = await db.find_one(Model=MySortClass, sort=sort_oprator)
+    assert result_one == obj_list[2]
+
+    sort_oprator = ["attr_3", 1]
+    with pytest.raises(
+        TypeError,
+        match='sort argument must be a SortOperator from pyodmongo.queries. If you really need to make a very specific sort, use "raw_sort" argument',
+    ):
+        result_one = await db.find_one(Model=MySortClass, sort=sort_oprator)
+
+    with pytest.raises(
+        TypeError,
+        match='sort argument must be a SortOperator from pyodmongo.queries. If you really need to make a very specific sort, use "raw_sort" argument',
+    ):
+        result_many = await db.find_many(Model=MySortClass, sort=sort_oprator)
+
+
+class ClassWithDate(DbModel):
+    name: str
+    date: datetime
+    _collection: ClassVar = "class_with_date"
+
+
+@pytest_asyncio.fixture()
+async def drop_collection_class_with_date():
+    await db._db[ClassWithDate._collection].drop()
+    yield
+    await db._db[ClassWithDate._collection].drop()
+
+
+@pytest.mark.asyncio
+async def test_save_and_retrieve_objs_with_datetime(drop_collection_class_with_date):
+
+    tz = timezone(timedelta(hours=-3))
+    date = datetime(
+        year=2024,
+        month=4,
+        day=24,
+        hour=23,
+        minute=0,
+        second=0,
+        tzinfo=tz,
+    )
+    obj = ClassWithDate(name="A name", date=date)
+    await db.save(obj)
+    query = (ClassWithDate.date >= datetime(2024, 4, 24, 22, 30, 0, tzinfo=tz)) & (
+        ClassWithDate.date <= datetime(2024, 4, 24, 23, 30, 0, tzinfo=tz)
+    )
+    obj_found: ClassWithDate = await db.find_one(Model=ClassWithDate, query=query)
+    assert obj_found.date == date
